import { EntityManager, FindManyOptions, FindOneOptions, FindOptionsRelations, ObjectLiteral, Repository } from 'typeorm';
import { NonNullableProperties } from '../types.js';
/**
 * An abstract class for a repository.
 * @typeParam M - Type of the model.
 * @typeParam RQ - Type of possible request.
 * @typeParam RSP - Type of possible response.
 */
export declare abstract class AbstractRepository<M extends ObjectLiteral, RQ, RSP, D extends Record<string, object> = Record<string, never>> {
    name: string;
    protected repository?: Repository<M>;
    protected abstract dependencies: Partial<D>;
    constructor(name: string);
    protected abstract dependenciesMet(): boolean;
    protected isInitialized(): this is {
        repository: Repository<M>;
        dependencies: NonNullableProperties<D>;
    };
    protected throwUninitializedRepositoryError(): never;
    abstract initialize(entityManager: EntityManager): void;
    create(data?: RQ): Promise<M>;
    abstract write(model: M, data: Partial<RQ>): Promise<void>;
    save(model: M): Promise<M>;
    find(options?: FindManyOptions<M>): Promise<M[]>;
    findOne(options: FindOneOptions<M>): Promise<M | null>;
    findOneOrFail(options: FindOneOptions<M>): Promise<M>;
    abstract format(model: M): Promise<RSP>;
    remove(model: M): Promise<void>;
    protected getDefaultFindOptionsRelations(): FindOptionsRelations<M> | undefined;
    setDependencies(dependencies: D): void;
}
//# sourceMappingURL=abstractRepository.d.ts.map